netapp_ontap.models.s3_bucket_policy_statement API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.s3_bucket_policy_statement`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class S3BucketPolicyStatementSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the S3BucketPolicyStatement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `actions GET POST PATCH`

    The actions field of the s3_bucket_policy_statement.

    Example: ["GetObject","PutObject","DeleteObject","ListBucket"]

  `conditions GET POST PATCH`

    Specifies bucket policy conditions.

  `effect GET POST PATCH`

    Specifies whether access is allowed or denied when a user requests the specific action. If access (to allow) is not granted explicitly to a resource, access is implicitly denied. Access can also be denied explicitly to a resource, in order to make sure that a user cannot access it, even if a different policy grants access.

    Valid choices:

    - allow
    - deny
  `principals GET POST PATCH`

    The principals field of the s3_bucket_policy_statement.

    Example: ["user1","group/grp1"]

  `resources GET POST PATCH`

    The resources field of the s3_bucket_policy_statement.

    Example: ["bucket1","bucket1/*"]

  `sid GET POST PATCH`

    Specifies the statement identifier used to differentiate between statements.

    Example: FullAccessToUser1